@@ -1,5 +1,5 @@
 #!/usr/local/bin/perl
-#  
+#
 #----------------------------------------------------------------------------
 #
 # This program was written by Clif Harden.
@@ -16,7 +16,7 @@
 # Revisions:
 # $Log: jpegLoad.pl,v $
 # Revision 1.2  2003/06/18 18:23:31  gbarr
-# Remove all references to :all as it is not recomended
+# Remove all references to :all as it is not recommended
 #
 # Revision 1.1  2001/03/12 14:01:46  gbarr
 # New contrib scripts from Clif Harden
@@ -38,13 +38,13 @@ my $errstr = 0;
 my $errmsg = "";
 
 $errmsg = ldap_error_text($errstr);
-   
+
 #
 # Initialize opt hash.
 # You can change the defaults to match your setup.
 # This can eliminate the need for many of the input
 # options on the command line.
-# 
+#
 my %opt = (
   'b' => 'dc=harden,dc=org',
   'h' => 'localhost',
@@ -56,7 +56,7 @@ my %opt = (
   'v' => 'commonName'
 );
 
-if ( @ARGV == 0 ) 
+if ( @ARGV == 0 )
 {
 #
 # print usage message.
@@ -66,14 +66,14 @@ Usage();
 
 #
 # Get command line options.
-# 
+#
 
 getopts('b:f:h:d:D:w:V:a:v:',\%opt);
 
 
-if ( !defined( $opt{'f'}) || !-e $opt{'f'} ) 
+if ( !defined( $opt{'f'}) || !-e $opt{'f'} )
 {
-# 
+#
 # No jpeg file specified or the file does not exist.
 #
 print "$opt{'f'}\n";
@@ -88,8 +88,9 @@ $, = undef;
 # Slurp all of the jpeg file in at once.
 #
 open(IN, "<$opt{'f'}");
-$_ = <IN>;   
-close(IN); 
+binmode(IN);
+$_ = <IN>;
+close(IN);
 
 #
 # build filter string
@@ -112,10 +113,10 @@ my $ldap = new Net::LDAP($opt{'h'},
 #
 # Bind to directory.
 #
-$ldap->ldapbind(password => "$opt{'w'}", dn => "$opt{'D'}", version => $opt{'V'}) or die $@;
+$ldap->bind($opt{'D'}, password => "$opt{'w'}", version => $opt{'V'}) or die $@;
 
 #
-# Search directory for record that matches filter 
+# Search directory for record that matches filter
 #
 my $mesg = $ldap->search(
   base   => $opt{'b'},
@@ -156,14 +157,14 @@ my @memberChange = ();
 push( @addMember, "jpegphoto" );     # attribute name
 push( @addMember, $_ );   # attribute value
 
-my $attr = $entry->get_attribute("jpegPhoto");
+my $attr = $entry->get_value("jpegPhoto");
 if(ref($attr))
 {
   #
   # Entry already has a jpegPhoto, replace it.
   #
   push( @memberChange, "replace" );     # ldap replace operation
-  push( @memberChange, \@addMember );     # ldap data to add 
+  push( @memberChange, \@addMember );     # ldap data to add
 }
 else
 {
@@ -171,18 +172,18 @@ else
   # Entry does not have a jpegPhoto, add it.
   #
   push( @memberChange, "add" );     # ldap add operation
-  push( @memberChange, \@addMember );     # ldap data to add 
-}                                                                          
+  push( @memberChange, \@addMember );     # ldap data to add
+}
 
 $mesg = $ldap->modify( $dn, changes => [ @memberChange ] ) or die $@;
 
-if ( $mesg->code ) 
+if ( $mesg->code )
 {
    $errstr = $mesg->code;
    print "Error code:  $errstr\n";
    $errmsg = ldap_error_text($errstr);
    print "$errmsg\n";
-   
+
 }
 
 $ldap->unbind;
@@ -195,11 +196,11 @@ sub Usage
    print( "Usage: [-b] <base> | [-h] <host> | [-d] <number> | [-D] <DN> | [-w] <password> | [-a] <attribute> | [-v] <data> | [-f] <jpeg file> \n" );
    print( "\t-b    Search base.\n" );
    print( "\t-d    Debug mode.  Display debug messages to stdout.\n" );
-   print( "\t-D    Authenication Distingushed Name.\n" );
+   print( "\t-D    Authentication Distinguished Name.\n" );
    print( "\t-f    JPEG file to load in to attribute jpegPhoto.\n" );
    print( "\t      Required input option.\n" );
    print( "\t-h    LDAP directory host computer.\n" );
-   print( "\t-w    Authenication password.\n" );
+   print( "\t-w    Authentication password.\n" );
    print( "\t-a    Attribute that will be incorporated into the search filter.\n" );
    print( "\t-v    Data that will be incorporated into the search filter.\n" );
    print( "\t-V    LDAP version of the LDAP directory.\n" );
@@ -210,7 +211,7 @@ sub Usage
    print( "\n" );
    print( "\n" );
    exit( 1 );
-}                                                                               
+}
 
 __END__
 
@@ -220,8 +221,8 @@ jpegLoad.pl -  A script to load a jpeg picture into the jpegPhoto attribute of a
 
 =head1 SYNOPSIS
 
-The intent of this script is to show the user how to load a 
-picture that is in jpeg format into the jpegPhoto attribute of 
+The intent of this script is to show the user how to load a
+picture that is in jpeg format into the jpegPhoto attribute of
 a directory entry.
 The entry in question must have the schema defined to
 allow the loading of the jpegPhoto attribute.
@@ -236,11 +237,11 @@ to point to your file pathname of perl.
 
  -b    Search base.
  -d    Debug mode.  Display debug messages to stdout.
- -D    Distingushed Name for authenication purposes.
+ -D    Distinguished Name for authentication purposes.
  -f    JPEG file to load in to attribute jpegPhoto.
        Required input option and file must exist.
  -h    LDAP directory host computer.
- -w    Authenication password.
+ -w    Authentication password.
  -a    Attribute that will be incorporated into the search filter.
  -v    Data that will be incorporated into the search filter.
  -V    LDAP version of the LDAP directory.
@@ -250,8 +251,8 @@ to point to your file pathname of perl.
                     -w <password> -a <attribute> -v <data> \
                     -f <jpeg file>
 
-Inside the script is a opt hash that can be initialized to 
-default values that can eliminate the need for many of the 
+Inside the script is a opt hash that can be initialized to
+default values that can eliminate the need for many of the
 input options on the command line.
 
 -------------------------------------------------------------------
@@ -259,26 +260,26 @@ input options on the command line.
 =head1 REQUIREMENTS
 
 To use this program you will need the following.
- 
+
 At least PERL version 5.004.  You can get a stable version of PERL
 from the following URL;
    http://cpan.org/src/index.html
- 
+
 Perl LDAP module.  You can get this from the following URL;
    ftp://ftp.duke.edu/pub/CPAN/modules/by-module/Net/
- 
+
 Bundled inside each PERL module is instructions on how to install the
 module into your PERL system.
- 
+
 -------------------------------------------------------------------
 
 =head1 INSTALLING THE SCRIPT
 
 Install the jpegLoad.pl script anywhere you wish, I suggest
 /usr/local/bin/jpegLoad.pl.
- 
+
 -------------------------------------------------------------------
- 
+
 Since the script is in PERL, feel free to modify it if it does not
 meet your needs.  This is one of the main reasons I did it in PERL.
 If you make an addition to the code that you feel other individuals
