@@ -25,9 +25,11 @@ use Net::LDAP::Constant qw(
   LDAP_CONTROL_SYNC_DONE
   LDAP_CONTROL_ASSERTION
   LDAP_CONTROL_RELAX
+  LDAP_CONTROL_DONTUSECOPY
+  LDAP_CONTROL_TREE_DELETE
 );
 
-our $VERSION = '0.17';
+our $VERSION = '0.19';
 
 my %Pkg2Type = (
 
@@ -59,6 +61,8 @@ my %Pkg2Type = (
   'Net::LDAP::Control::SyncDone'	=> LDAP_CONTROL_SYNC_DONE,
   'Net::LDAP::Control::Assertion'	=> LDAP_CONTROL_ASSERTION,
   'Net::LDAP::Control::Relax'		=> LDAP_CONTROL_RELAX,
+  'Net::LDAP::Control::DontUseCopy'	=> LDAP_CONTROL_DONTUSECOPY,
+  'Net::LDAP::Control::TreeDelete'	=> LDAP_CONTROL_TREE_DELETE,
   #
   #LDAP_CONTROL_PWEXPIRED
   #LDAP_CONTROL_PWEXPIRING
@@ -311,6 +315,7 @@ for this method is to return TRUE if there is no error, but sub-classes may over
 L<Net::LDAP>,
 L<Net::LDAP::RootDSE>,
 L<Net::LDAP::Control::Assertion>,
+L<Net::LDAP::Control::DontUseCopy>,
 L<Net::LDAP::Control::EntryChange>,
 L<Net::LDAP::Control::ManageDsaIT>,
 L<Net::LDAP::Control::MatchedValues>,
@@ -326,6 +331,7 @@ L<Net::LDAP::Control::SortResult>,
 L<Net::LDAP::Control::SyncDone>,
 L<Net::LDAP::Control::SyncRequest>,
 L<Net::LDAP::Control::SyncState>,
+L<Net::LDAP::Control::TreeDelete>,
 L<Net::LDAP::Control::VLV>,
 L<Net::LDAP::Control::VLVResponse>
 
